require 'spec_helper'
require 'octokit'

describe Octokom::Client do
  let(:netrc) { {Octokom::Client::KEY => credentials} }

  before do
    allow(Netrc).to receive(:new) { netrc }
  end

  describe '#authenticate' do
    context 'with valid netrc file' do
      let(:credentials) { ['fox', 'chunky'] }

      it 'parses the credentials' do
        auth = Octokom::Client.authenticate
        expect(auth.token).to eq('chunky')
      end

      it 'returns a client instance' do
        auth = Octokom::Client.authenticate
        expect(auth).to be_kind_of(Octokom::Client)
      end

      it 'handels invalid API tokens on GitHub'
    end

    context 'with invalid netrc file' do
      let(:credentials) { [] }
      let(:octokit)     { double }
      let(:auth)        { double(:token => nil) }

      before do
        allow_any_instance_of(Octokom::Client).to receive(:ask_for_login) { 'fox' }
        allow_any_instance_of(Octokom::Client).to receive(:ask_for_password) { 'bacon' }
        allow(Octokit::Client).to receive(:new) { octokit }
        allow(octokit).to receive(:create_authorization) { auth }
        allow(netrc).to receive(:save) { true }
        allow(STDOUT).to receive(:puts)
      end

      it 'initializes a new Octokit client' do
        expect(Octokit::Client).to receive(:new).with(login: 'fox', password: 'bacon')
        Octokom::Client.authenticate
      end

      it 'creates a authorization token' do
        expect(octokit).to receive(:create_authorization)
        Octokom::Client.authenticate
      end

      it 'creates a authorization token' do
        expect(netrc).to receive(:save)
        Octokom::Client.authenticate
      end
    end
  end

  describe '#client' do
    let(:credentials) { ['fox', 'chunky'] }

    it 'initializes a new Octokit client' do
      auth = Octokom::Client.authenticate
      expect(auth.client).to be_kind_of(Octokit::Client)
    end
  end
end
