require 'spec_helper'
require 'octokom/command/issue'

describe Issue do
  describe '#create' do
    let(:git)    { double(repo_path: 'user/repo') }
    let(:auth)   { double(client: client) }
    let(:client) { double }

    before do
      allow(Octokom::Repository).to receive(:new) { git }
      allow(Octokom::Client).to receive(:authenticate) { auth }
      allow(client).to receive(:create_issue)
      allow_any_instance_of(Octokom::Command).to receive(:print)
      allow_any_instance_of(Octokom::Command).to receive(:puts)
    end

    subject(:cmd) { Issue.new('test') }

    context 'when no "title" option is set' do
      let(:options) { %w(create) }

      it 'opens the editor' do
        expect(Octokom::Editor).to receive(:open).with(git, nil, nil) { ['Bacon'] }

        cmd.run(options)
      end

      it 'exits when no "title" can be parsed'
    end

    context 'when "title" option is set' do
      let(:options) { %w(create --title Bacon) }

      it 'creates a GitHub issue' do
        expect(client).to receive(:create_issue).with('user/repo', 'Bacon', nil)

        cmd.run(options)
      end

      context 'and "dry-run" tag is set' do
        it 'does not create a GitHub issue' do
          expect(client).to_not receive(:create_issue)

          cmd.run(options.push('--dry-run'))
        end
      end

      context 'and "editor" tag is set' do
        it 'opens the editor' do
          expect(Octokom::Editor).to receive(:open).with(git, 'Bacon', nil) { ['Bacon'] }

          cmd.run(options.push('--editor'))
        end
      end
    end
  end
end
