require 'spec_helper'

describe Octokom::Command do
  describe '#flag' do
    subject(:cmd) do
      class FlagCmd < Octokom::Command
        flag ['--bacon'], 'Bacon'
        execute { @bacon }
      end

      FlagCmd.new('test')
    end

    it 'returns true when the flag option is set' do
      expect(cmd.run(['--bacon'])).to be(true)
    end

    it 'returns nil when the flag option is not set' do
      expect(cmd.run([])).to be_nil
    end
  end

  describe '#option' do
    subject(:cmd) do
      class OptionCmd < Octokom::Command
        option ['--bacon'], 'Bacon'
        execute { @bacon }
      end

      OptionCmd.new('test')
    end

    it 'returns the the option value' do
      expect(cmd.run(['--bacon', '1'])).to eq('1')
    end

    it 'returns nil when the option is not set' do
      expect(cmd.run([])).to be_nil
    end
  end

  describe '#git' do
    subject(:cmd) do
      class GitCmd < Octokom::Command
        execute { git }
      end

      GitCmd.new('test')
    end

    let(:git) { double }

    before do
      allow(Octokom::Repository).to receive(:new) { git }
    end

    it 'initializes a Repository instance' do
      expect(cmd.run([])).to eq(git)
    end
  end
end
