require 'spec_helper'

describe Octokom::Repository do
  subject(:repo) { Octokom::Repository.new(false) }

  describe '#repo_path' do
    context 'when a remote path is defined' do
      before do
        allow(repo).to receive(:remote_url) { 'https://github.com/fox-1/bacon.rb.git' }
      end

      it 'returns the GitHub repository path' do
        expect(repo.repo_path).to eq('fox-1/bacon.rb')
      end
    end

    context 'when no remote path is defined' do
      let(:stdout) { double }

      before do
        allow(repo).to receive(:remote_url) { nil }
        allow(stdout).to receive(:puts)
        allow(repo).to receive(:puts) { |msg| stdout.puts(msg) }
      end

      it 'prints a error message and exits' do
        expect(stdout).to receive(:puts).with(/Git remote not defined/)
        expect { repo.repo_path }.to raise_error(SystemExit)
      end
    end
  end

  describe '#pending_commits?' do
    before do
      allow(repo).to receive(:head_branch) { 'test-1' }
    end

    context 'with pending commits' do
      before do
        allow(repo).to receive(:last_commits) { load_example(:git_branch_pending_commits) }
      end

      specify { expect(repo.pending_commits?).to be(true) }
    end

    context 'with no pending commits' do
      before do
        allow(repo).to receive(:last_commits) { load_example(:git_branch_no_pending_commits) }
      end

      specify { expect(repo.pending_commits?).to be(false) }
    end

    context 'with no remote branch' do
      before do
        allow(repo).to receive(:last_commits) { load_example(:git_branch_no_remote) }
      end

      specify { expect(repo.pending_commits?).to be(true) }
    end
  end

  describe '#last_commit_message' do
    before do
      allow(repo).to receive(:git) { load_example(:git_log_commits) }
    end

    it 'returns the commit message' do
      expect(repo.last_commit_message).to eq('Add all the features')
    end
  end
end
