require 'spec_helper'

class Cli
  include Octokom::Shell
end

describe Octokom::Shell do
  let(:stdout) { double }

  subject(:cli) { Cli.new }

  before do
    allow(cli).to receive(:puts) do |msg|
      stdout.puts(msg)
    end

    allow(cli).to receive(:print) do |msg|
      stdout.print(msg)
    end
  end

  describe '.info' do
    it 'prints a message' do
      expect(stdout).to receive(:puts).with('Info    Test')
      cli.info('Test')
    end
  end

  describe '.error' do
    it 'prints a message and returns with an error code' do
      expect(stdout).to receive(:puts).with('Error   Test')
      expect { cli.error('Test') }.to raise_error(SystemExit)
    end
  end

  describe '.task' do
    before do
      allow(stdout).to receive(:print)
      allow(stdout).to receive(:puts)
    end

    it 'updates a message' do
      expect(stdout).to receive(:print).with('Waiting Test')
      expect(stdout).to receive(:print).with("\r")
      expect(stdout).to receive(:print).with('Done    Test')
      expect(stdout).to receive(:puts).with(nil)
      cli.task('Test') { 'Ok' }
    end

    it 'executes a task' do
      expect { |block| cli.task('Test', &block) }.to yield_with_no_args
    end
  end
end
